[gnome-disk-utility] Rename palimpsest(1) to gnome-disks(1)
- From: David Zeuthen <davidz src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gnome-disk-utility] Rename palimpsest(1) to gnome-disks(1)
- Date: Wed, 2 May 2012 21:06:21 +0000 (UTC)
commit cee43a5bb94a478ec70628d529865d2ea403fffe
Author: David Zeuthen <davidz redhat com>
Date: Wed May 2 17:03:28 2012 -0400
Rename palimpsest(1) to gnome-disks(1)
Also move files/dirs around to reflect this change.
Signed-off-by: David Zeuthen <davidz redhat com>
configure.ac | 4 +-
data/Makefile.am | 2 +-
...alimpsest.desktop.in => gnome-disks.desktop.in} | 4 +-
data/icons/16x16/Makefile.am | 2 +-
.../16x16/{palimpsest.png => gnome-disks.png} | Bin 1090 -> 1090 bytes
data/icons/22x22/Makefile.am | 2 +-
.../22x22/{palimpsest.png => gnome-disks.png} | Bin 1548 -> 1548 bytes
data/icons/24x24/Makefile.am | 2 +-
.../24x24/{palimpsest.png => gnome-disks.png} | Bin 1578 -> 1578 bytes
data/icons/256x256/Makefile.am | 2 +-
.../256x256/{palimpsest.png => gnome-disks.png} | Bin 42032 -> 42032 bytes
data/icons/32x32/Makefile.am | 2 +-
.../32x32/{palimpsest.png => gnome-disks.png} | Bin 2334 -> 2334 bytes
data/icons/48x48/Makefile.am | 2 +-
.../48x48/{palimpsest.png => gnome-disks.png} | Bin 3644 -> 3644 bytes
data/icons/src/{palimpsest.svg => gnome-disks.svg} | 0
data/ui/Makefile.am | 2 +-
data/ui/{palimpsest.ui => disks.ui} | 4 +-
po/POTFILES.in | 48 ++++++++++----------
src/Makefile.am | 2 +-
.../Makefile.am | 0
.../main.c | 0
src/{palimpsest => disks}/Makefile.am | 12 +++---
src/{palimpsest => disks}/gdu.h | 0
src/{palimpsest => disks}/gduapplication.c | 4 +-
src/{palimpsest => disks}/gduapplication.h | 0
src/{palimpsest => disks}/gduatasmartdialog.c | 0
src/{palimpsest => disks}/gduatasmartdialog.h | 0
.../gduchangepassphrasedialog.c | 0
.../gduchangepassphrasedialog.h | 0
.../gducreatediskimagedialog.c | 0
.../gducreatediskimagedialog.h | 0
.../gducreatefilesystemwidget.c | 0
.../gducreatefilesystemwidget.h | 0
.../gducreatepartitiondialog.c | 0
.../gducreatepartitiondialog.h | 0
src/{palimpsest => disks}/gducrypttabdialog.c | 0
src/{palimpsest => disks}/gducrypttabdialog.h | 0
src/{palimpsest => disks}/gdudevicetreemodel.c | 0
src/{palimpsest => disks}/gdudevicetreemodel.h | 0
src/{palimpsest => disks}/gduenums.h | 0
src/{palimpsest => disks}/gduenumtypes.c.template | 0
src/{palimpsest => disks}/gduenumtypes.h.template | 0
src/{palimpsest => disks}/gduestimator.c | 0
src/{palimpsest => disks}/gduestimator.h | 0
src/{palimpsest => disks}/gdufilesystemdialog.c | 0
src/{palimpsest => disks}/gdufilesystemdialog.h | 0
src/{palimpsest => disks}/gduformatdiskdialog.c | 0
src/{palimpsest => disks}/gduformatdiskdialog.h | 0
src/{palimpsest => disks}/gduformatvolumedialog.c | 0
src/{palimpsest => disks}/gduformatvolumedialog.h | 0
src/{palimpsest => disks}/gdufstabdialog.c | 0
src/{palimpsest => disks}/gdufstabdialog.h | 0
src/{palimpsest => disks}/gdupartitiondialog.c | 0
src/{palimpsest => disks}/gdupartitiondialog.h | 0
.../gdupasswordstrengthwidget.c | 0
.../gdupasswordstrengthwidget.h | 0
.../gdurestorediskimagedialog.c | 0
.../gdurestorediskimagedialog.h | 0
src/{palimpsest => disks}/gdutypes.h | 0
src/{palimpsest => disks}/gduunlockdialog.c | 0
src/{palimpsest => disks}/gduunlockdialog.h | 0
src/{palimpsest => disks}/gduutils.c | 0
src/{palimpsest => disks}/gduutils.h | 0
src/{palimpsest => disks}/gduvolumegrid.c | 0
src/{palimpsest => disks}/gduvolumegrid.h | 0
src/{palimpsest => disks}/gduwindow.c | 6 +-
src/{palimpsest => disks}/gduwindow.h | 0
src/{palimpsest => disks}/main.c | 0
69 files changed, 50 insertions(+), 50 deletions(-)
---
diff --git a/configure.ac b/configure.ac
index 08a8aba..7b76dc1 100644
--- a/configure.ac
+++ b/configure.ac
@@ -77,8 +77,8 @@ AC_SUBST([AM_LDFLAGS])
AC_CONFIG_FILES([
Makefile
src/Makefile
-src/palimpsest/Makefile
-src/gnome-disk-image-mounter/Makefile
+src/disks/Makefile
+src/disk-image-mounter/Makefile
po/Makefile.in
data/Makefile
data/icons/Makefile
diff --git a/data/Makefile.am b/data/Makefile.am
index 53df243..661b35b 100644
--- a/data/Makefile.am
+++ b/data/Makefile.am
@@ -3,7 +3,7 @@ NULL =
SUBDIRS = ui icons
desktopdir = $(datadir)/applications
-desktop_in_files = palimpsest.desktop.in gnome-disk-image-mounter.desktop.in
+desktop_in_files = gnome-disks.desktop.in gnome-disk-image-mounter.desktop.in
desktop_DATA = $(desktop_in_files:.desktop.in=.desktop)
@INTLTOOL_DESKTOP_RULE@
diff --git a/data/palimpsest.desktop.in b/data/gnome-disks.desktop.in
similarity index 85%
rename from data/palimpsest.desktop.in
rename to data/gnome-disks.desktop.in
index 51764d4..ac5b26a 100644
--- a/data/palimpsest.desktop.in
+++ b/data/gnome-disks.desktop.in
@@ -1,8 +1,8 @@
[Desktop Entry]
_Name=Disks
_Comment=Manage Drives and Media
-Exec=palimpsest
-Icon=palimpsest
+Exec=gnome-disks
+Icon=gnome-disks
Terminal=false
Type=Application
StartupNotify=true
diff --git a/data/icons/16x16/Makefile.am b/data/icons/16x16/Makefile.am
index 25db659..254ddcd 100644
--- a/data/icons/16x16/Makefile.am
+++ b/data/icons/16x16/Makefile.am
@@ -2,7 +2,7 @@ NULL =
icondir = $(datadir)/icons/hicolor/16x16/apps
icon_DATA = \
- palimpsest.png \
+ gnome-disks.png \
$(NULL)
EXTRA_DIST = \
diff --git a/data/icons/16x16/palimpsest.png b/data/icons/16x16/gnome-disks.png
similarity index 100%
rename from data/icons/16x16/palimpsest.png
rename to data/icons/16x16/gnome-disks.png
diff --git a/data/icons/22x22/Makefile.am b/data/icons/22x22/Makefile.am
index 510b976..6277f68 100644
--- a/data/icons/22x22/Makefile.am
+++ b/data/icons/22x22/Makefile.am
@@ -2,7 +2,7 @@ NULL =
icondir = $(datadir)/icons/hicolor/22x22/apps
icon_DATA = \
- palimpsest.png \
+ gnome-disks.png \
$(NULL)
EXTRA_DIST = \
diff --git a/data/icons/22x22/palimpsest.png b/data/icons/22x22/gnome-disks.png
similarity index 100%
rename from data/icons/22x22/palimpsest.png
rename to data/icons/22x22/gnome-disks.png
diff --git a/data/icons/24x24/Makefile.am b/data/icons/24x24/Makefile.am
index 347d9fb..f6a981a 100644
--- a/data/icons/24x24/Makefile.am
+++ b/data/icons/24x24/Makefile.am
@@ -2,7 +2,7 @@ NULL =
icondir = $(datadir)/icons/hicolor/24x24/apps
icon_DATA = \
- palimpsest.png \
+ gnome-disks.png \
$(NULL)
EXTRA_DIST = \
diff --git a/data/icons/24x24/palimpsest.png b/data/icons/24x24/gnome-disks.png
similarity index 100%
rename from data/icons/24x24/palimpsest.png
rename to data/icons/24x24/gnome-disks.png
diff --git a/data/icons/256x256/Makefile.am b/data/icons/256x256/Makefile.am
index dc7e73a..74f5bd0 100644
--- a/data/icons/256x256/Makefile.am
+++ b/data/icons/256x256/Makefile.am
@@ -2,7 +2,7 @@ NULL =
icondir = $(datadir)/icons/hicolor/256x256/apps
icon_DATA = \
- palimpsest.png \
+ gnome-disks.png \
$(NULL)
EXTRA_DIST = \
diff --git a/data/icons/256x256/palimpsest.png b/data/icons/256x256/gnome-disks.png
similarity index 100%
rename from data/icons/256x256/palimpsest.png
rename to data/icons/256x256/gnome-disks.png
diff --git a/data/icons/32x32/Makefile.am b/data/icons/32x32/Makefile.am
index 9a2bc76..34f689a 100644
--- a/data/icons/32x32/Makefile.am
+++ b/data/icons/32x32/Makefile.am
@@ -2,7 +2,7 @@ NULL =
icondir = $(datadir)/icons/hicolor/32x32/apps
icon_DATA = \
- palimpsest.png \
+ gnome-disks.png \
$(NULL)
EXTRA_DIST = \
diff --git a/data/icons/32x32/palimpsest.png b/data/icons/32x32/gnome-disks.png
similarity index 100%
rename from data/icons/32x32/palimpsest.png
rename to data/icons/32x32/gnome-disks.png
diff --git a/data/icons/48x48/Makefile.am b/data/icons/48x48/Makefile.am
index ad38bea..e8e2adc 100644
--- a/data/icons/48x48/Makefile.am
+++ b/data/icons/48x48/Makefile.am
@@ -2,7 +2,7 @@ NULL =
icondir = $(datadir)/icons/hicolor/48x48/apps
icon_DATA = \
- palimpsest.png \
+ gnome-disks.png \
$(NULL)
EXTRA_DIST = \
diff --git a/data/icons/48x48/palimpsest.png b/data/icons/48x48/gnome-disks.png
similarity index 100%
rename from data/icons/48x48/palimpsest.png
rename to data/icons/48x48/gnome-disks.png
diff --git a/data/icons/src/palimpsest.svg b/data/icons/src/gnome-disks.svg
similarity index 100%
rename from data/icons/src/palimpsest.svg
rename to data/icons/src/gnome-disks.svg
diff --git a/data/ui/Makefile.am b/data/ui/Makefile.am
index 1b3aec3..08c7e48 100644
--- a/data/ui/Makefile.am
+++ b/data/ui/Makefile.am
@@ -10,7 +10,7 @@ ui_DATA = \
edit-partition-dialog.ui \
edit-gpt-partition-dialog.ui \
edit-dos-partition-dialog.ui \
- palimpsest.ui \
+ disks.ui \
unlock-device-dialog.ui \
format-volume-dialog.ui \
smart-dialog.ui \
diff --git a/data/ui/palimpsest.ui b/data/ui/disks.ui
similarity index 99%
rename from data/ui/palimpsest.ui
rename to data/ui/disks.ui
index 275a24d..f16bd71 100644
--- a/data/ui/palimpsest.ui
+++ b/data/ui/disks.ui
@@ -202,7 +202,7 @@
</object>
</child>
</object>
- <object class="GtkWindow" id="palimpsest-window">
+ <object class="GtkWindow" id="disks-window">
<property name="can_focus">False</property>
<property name="border_width">12</property>
<property name="default_width">400</property>
@@ -292,7 +292,7 @@
</packing>
</child>
<child>
- <object class="GtkNotebook" id="palimpsest-notebook">
+ <object class="GtkNotebook" id="disks-notebook">
<property name="visible">True</property>
<property name="can_focus">True</property>
<property name="margin_left">6</property>
diff --git a/po/POTFILES.in b/po/POTFILES.in
index c21ecce..0578761 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -2,7 +2,7 @@
# List of source files containing translatable strings.
# Please keep this file sorted alphabetically.
data/gnome-disk-image-mounter.desktop.in
-data/palimpsest.desktop.in
+data/gnome-disks.desktop.in
[type: gettext/glade]data/ui/about-dialog.ui
[type: gettext/glade]data/ui/app-menu.ui
[type: gettext/glade]data/ui/change-passphrase-dialog.ui
@@ -17,29 +17,29 @@ data/palimpsest.desktop.in
[type: gettext/glade]data/ui/filesystem-create.ui
[type: gettext/glade]data/ui/format-disk-dialog.ui
[type: gettext/glade]data/ui/format-volume-dialog.ui
-[type: gettext/glade]data/ui/palimpsest.ui
+[type: gettext/glade]data/ui/disks.ui
[type: gettext/glade]data/ui/restore-disk-image-dialog.ui
[type: gettext/glade]data/ui/smart-dialog.ui
[type: gettext/glade]data/ui/unlock-device-dialog.ui
-src/gnome-disk-image-mounter/main.c
-src/palimpsest/gduapplication.c
-src/palimpsest/gduatasmartdialog.c
-src/palimpsest/gduchangepassphrasedialog.c
-src/palimpsest/gducreatediskimagedialog.c
-src/palimpsest/gducreatefilesystemwidget.c
-src/palimpsest/gducreatepartitiondialog.c
-src/palimpsest/gducrypttabdialog.c
-src/palimpsest/gdudevicetreemodel.c
-src/palimpsest/gduestimator.c
-src/palimpsest/gdufilesystemdialog.c
-src/palimpsest/gduformatdiskdialog.c
-src/palimpsest/gduformatvolumedialog.c
-src/palimpsest/gdufstabdialog.c
-src/palimpsest/gdupartitiondialog.c
-src/palimpsest/gdupasswordstrengthwidget.c
-src/palimpsest/gdurestorediskimagedialog.c
-src/palimpsest/gduunlockdialog.c
-src/palimpsest/gduutils.c
-src/palimpsest/gduvolumegrid.c
-src/palimpsest/gduwindow.c
-src/palimpsest/main.c
+src/disk-image-mounter/main.c
+src/disks/gduapplication.c
+src/disks/gduatasmartdialog.c
+src/disks/gduchangepassphrasedialog.c
+src/disks/gducreatediskimagedialog.c
+src/disks/gducreatefilesystemwidget.c
+src/disks/gducreatepartitiondialog.c
+src/disks/gducrypttabdialog.c
+src/disks/gdudevicetreemodel.c
+src/disks/gduestimator.c
+src/disks/gdufilesystemdialog.c
+src/disks/gduformatdiskdialog.c
+src/disks/gduformatvolumedialog.c
+src/disks/gdufstabdialog.c
+src/disks/gdupartitiondialog.c
+src/disks/gdupasswordstrengthwidget.c
+src/disks/gdurestorediskimagedialog.c
+src/disks/gduunlockdialog.c
+src/disks/gduutils.c
+src/disks/gduvolumegrid.c
+src/disks/gduwindow.c
+src/disks/main.c
diff --git a/src/Makefile.am b/src/Makefile.am
index 39fa482..bdcbc18 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -1,4 +1,4 @@
-SUBDIRS = palimpsest gnome-disk-image-mounter
+SUBDIRS = disks disk-image-mounter
clean-local :
rm -f *~
diff --git a/src/gnome-disk-image-mounter/Makefile.am b/src/disk-image-mounter/Makefile.am
similarity index 100%
rename from src/gnome-disk-image-mounter/Makefile.am
rename to src/disk-image-mounter/Makefile.am
diff --git a/src/gnome-disk-image-mounter/main.c b/src/disk-image-mounter/main.c
similarity index 100%
rename from src/gnome-disk-image-mounter/main.c
rename to src/disk-image-mounter/main.c
diff --git a/src/palimpsest/Makefile.am b/src/disks/Makefile.am
similarity index 92%
rename from src/palimpsest/Makefile.am
rename to src/disks/Makefile.am
index d06f2ae..3be8b82 100644
--- a/src/palimpsest/Makefile.am
+++ b/src/disks/Makefile.am
@@ -2,7 +2,7 @@
NULL =
BUILT_SOURCES =
-bin_PROGRAMS = palimpsest
+bin_PROGRAMS = gnome-disks
gduenumtypes.h: gduenums.h gduenumtypes.h.template
( top_builddir=`cd $(top_builddir) && pwd`; \
@@ -22,7 +22,7 @@ enum_built_sources = \
BUILT_SOURCES += $(enum_built_sources)
-palimpsest_SOURCES = \
+gnome_disks_SOURCES = \
main.c \
gdu.h \
gduapplication.h gduapplication.c \
@@ -50,15 +50,15 @@ palimpsest_SOURCES = \
$(enum_built_sources) \
$(NULL)
-palimpsest_CPPFLAGS = \
+gnome_disks_CPPFLAGS = \
-I$(top_srcdir)/src/ \
-I$(top_builddir)/src/ \
-DPACKAGE_DATA_DIR=\""$(datadir)"\" \
- -DG_LOG_DOMAIN=\"Palimpsest\" \
+ -DG_LOG_DOMAIN=\"GNOME-Disks\" \
-DGNOMELOCALEDIR=\""$(datadir)/locale"\" \
$(NULL)
-palimpsest_CFLAGS = \
+gnome_disks_CFLAGS = \
$(GLIB2_CFLAGS) \
$(UDISKS2_CFLAGS) \
$(GTK3_CFLAGS) \
@@ -68,7 +68,7 @@ palimpsest_CFLAGS = \
-lm \
$(NULL)
-palimpsest_LDADD = \
+gnome_disks_LDADD = \
$(GLIB2_LIBS) \
$(UDISKS2_LIBS) \
$(GTK3_LIBS) \
diff --git a/src/palimpsest/gdu.h b/src/disks/gdu.h
similarity index 100%
rename from src/palimpsest/gdu.h
rename to src/disks/gdu.h
diff --git a/src/palimpsest/gduapplication.c b/src/disks/gduapplication.c
similarity index 98%
rename from src/palimpsest/gduapplication.c
rename to src/disks/gduapplication.c
index 1d1172a..938d5c0 100644
--- a/src/palimpsest/gduapplication.c
+++ b/src/disks/gduapplication.c
@@ -67,7 +67,7 @@ gdu_application_local_command_line (GApplication *_app,
GduApplication *app = GDU_APPLICATION (_app);
/* figure out if running from source tree */
- if (g_strcmp0 ((*arguments)[0], "./palimpsest") == 0)
+ if (g_strcmp0 ((*arguments)[0], "./gnome-disks") == 0)
app->running_from_source_tree = TRUE;
/* chain up */
@@ -200,7 +200,7 @@ gdu_application_new (void)
*
* has been resolved.
*/
- g_set_prgname ("palimpsest");
+ g_set_prgname ("gnome-disks");
gtk_init (NULL, NULL);
return G_APPLICATION (g_object_new (GDU_TYPE_APPLICATION,
"application-id", "org.gnome.DiskUtility",
diff --git a/src/palimpsest/gduapplication.h b/src/disks/gduapplication.h
similarity index 100%
rename from src/palimpsest/gduapplication.h
rename to src/disks/gduapplication.h
diff --git a/src/palimpsest/gduatasmartdialog.c b/src/disks/gduatasmartdialog.c
similarity index 100%
rename from src/palimpsest/gduatasmartdialog.c
rename to src/disks/gduatasmartdialog.c
diff --git a/src/palimpsest/gduatasmartdialog.h b/src/disks/gduatasmartdialog.h
similarity index 100%
rename from src/palimpsest/gduatasmartdialog.h
rename to src/disks/gduatasmartdialog.h
diff --git a/src/palimpsest/gduchangepassphrasedialog.c b/src/disks/gduchangepassphrasedialog.c
similarity index 100%
rename from src/palimpsest/gduchangepassphrasedialog.c
rename to src/disks/gduchangepassphrasedialog.c
diff --git a/src/palimpsest/gduchangepassphrasedialog.h b/src/disks/gduchangepassphrasedialog.h
similarity index 100%
rename from src/palimpsest/gduchangepassphrasedialog.h
rename to src/disks/gduchangepassphrasedialog.h
diff --git a/src/palimpsest/gducreatediskimagedialog.c b/src/disks/gducreatediskimagedialog.c
similarity index 100%
rename from src/palimpsest/gducreatediskimagedialog.c
rename to src/disks/gducreatediskimagedialog.c
diff --git a/src/palimpsest/gducreatediskimagedialog.h b/src/disks/gducreatediskimagedialog.h
similarity index 100%
rename from src/palimpsest/gducreatediskimagedialog.h
rename to src/disks/gducreatediskimagedialog.h
diff --git a/src/palimpsest/gducreatefilesystemwidget.c b/src/disks/gducreatefilesystemwidget.c
similarity index 100%
rename from src/palimpsest/gducreatefilesystemwidget.c
rename to src/disks/gducreatefilesystemwidget.c
diff --git a/src/palimpsest/gducreatefilesystemwidget.h b/src/disks/gducreatefilesystemwidget.h
similarity index 100%
rename from src/palimpsest/gducreatefilesystemwidget.h
rename to src/disks/gducreatefilesystemwidget.h
diff --git a/src/palimpsest/gducreatepartitiondialog.c b/src/disks/gducreatepartitiondialog.c
similarity index 100%
rename from src/palimpsest/gducreatepartitiondialog.c
rename to src/disks/gducreatepartitiondialog.c
diff --git a/src/palimpsest/gducreatepartitiondialog.h b/src/disks/gducreatepartitiondialog.h
similarity index 100%
rename from src/palimpsest/gducreatepartitiondialog.h
rename to src/disks/gducreatepartitiondialog.h
diff --git a/src/palimpsest/gducrypttabdialog.c b/src/disks/gducrypttabdialog.c
similarity index 100%
rename from src/palimpsest/gducrypttabdialog.c
rename to src/disks/gducrypttabdialog.c
diff --git a/src/palimpsest/gducrypttabdialog.h b/src/disks/gducrypttabdialog.h
similarity index 100%
rename from src/palimpsest/gducrypttabdialog.h
rename to src/disks/gducrypttabdialog.h
diff --git a/src/palimpsest/gdudevicetreemodel.c b/src/disks/gdudevicetreemodel.c
similarity index 100%
rename from src/palimpsest/gdudevicetreemodel.c
rename to src/disks/gdudevicetreemodel.c
diff --git a/src/palimpsest/gdudevicetreemodel.h b/src/disks/gdudevicetreemodel.h
similarity index 100%
rename from src/palimpsest/gdudevicetreemodel.h
rename to src/disks/gdudevicetreemodel.h
diff --git a/src/palimpsest/gduenums.h b/src/disks/gduenums.h
similarity index 100%
rename from src/palimpsest/gduenums.h
rename to src/disks/gduenums.h
diff --git a/src/palimpsest/gduenumtypes.c.template b/src/disks/gduenumtypes.c.template
similarity index 100%
rename from src/palimpsest/gduenumtypes.c.template
rename to src/disks/gduenumtypes.c.template
diff --git a/src/palimpsest/gduenumtypes.h.template b/src/disks/gduenumtypes.h.template
similarity index 100%
rename from src/palimpsest/gduenumtypes.h.template
rename to src/disks/gduenumtypes.h.template
diff --git a/src/palimpsest/gduestimator.c b/src/disks/gduestimator.c
similarity index 100%
rename from src/palimpsest/gduestimator.c
rename to src/disks/gduestimator.c
diff --git a/src/palimpsest/gduestimator.h b/src/disks/gduestimator.h
similarity index 100%
rename from src/palimpsest/gduestimator.h
rename to src/disks/gduestimator.h
diff --git a/src/palimpsest/gdufilesystemdialog.c b/src/disks/gdufilesystemdialog.c
similarity index 100%
rename from src/palimpsest/gdufilesystemdialog.c
rename to src/disks/gdufilesystemdialog.c
diff --git a/src/palimpsest/gdufilesystemdialog.h b/src/disks/gdufilesystemdialog.h
similarity index 100%
rename from src/palimpsest/gdufilesystemdialog.h
rename to src/disks/gdufilesystemdialog.h
diff --git a/src/palimpsest/gduformatdiskdialog.c b/src/disks/gduformatdiskdialog.c
similarity index 100%
rename from src/palimpsest/gduformatdiskdialog.c
rename to src/disks/gduformatdiskdialog.c
diff --git a/src/palimpsest/gduformatdiskdialog.h b/src/disks/gduformatdiskdialog.h
similarity index 100%
rename from src/palimpsest/gduformatdiskdialog.h
rename to src/disks/gduformatdiskdialog.h
diff --git a/src/palimpsest/gduformatvolumedialog.c b/src/disks/gduformatvolumedialog.c
similarity index 100%
rename from src/palimpsest/gduformatvolumedialog.c
rename to src/disks/gduformatvolumedialog.c
diff --git a/src/palimpsest/gduformatvolumedialog.h b/src/disks/gduformatvolumedialog.h
similarity index 100%
rename from src/palimpsest/gduformatvolumedialog.h
rename to src/disks/gduformatvolumedialog.h
diff --git a/src/palimpsest/gdufstabdialog.c b/src/disks/gdufstabdialog.c
similarity index 100%
rename from src/palimpsest/gdufstabdialog.c
rename to src/disks/gdufstabdialog.c
diff --git a/src/palimpsest/gdufstabdialog.h b/src/disks/gdufstabdialog.h
similarity index 100%
rename from src/palimpsest/gdufstabdialog.h
rename to src/disks/gdufstabdialog.h
diff --git a/src/palimpsest/gdupartitiondialog.c b/src/disks/gdupartitiondialog.c
similarity index 100%
rename from src/palimpsest/gdupartitiondialog.c
rename to src/disks/gdupartitiondialog.c
diff --git a/src/palimpsest/gdupartitiondialog.h b/src/disks/gdupartitiondialog.h
similarity index 100%
rename from src/palimpsest/gdupartitiondialog.h
rename to src/disks/gdupartitiondialog.h
diff --git a/src/palimpsest/gdupasswordstrengthwidget.c b/src/disks/gdupasswordstrengthwidget.c
similarity index 100%
rename from src/palimpsest/gdupasswordstrengthwidget.c
rename to src/disks/gdupasswordstrengthwidget.c
diff --git a/src/palimpsest/gdupasswordstrengthwidget.h b/src/disks/gdupasswordstrengthwidget.h
similarity index 100%
rename from src/palimpsest/gdupasswordstrengthwidget.h
rename to src/disks/gdupasswordstrengthwidget.h
diff --git a/src/palimpsest/gdurestorediskimagedialog.c b/src/disks/gdurestorediskimagedialog.c
similarity index 100%
rename from src/palimpsest/gdurestorediskimagedialog.c
rename to src/disks/gdurestorediskimagedialog.c
diff --git a/src/palimpsest/gdurestorediskimagedialog.h b/src/disks/gdurestorediskimagedialog.h
similarity index 100%
rename from src/palimpsest/gdurestorediskimagedialog.h
rename to src/disks/gdurestorediskimagedialog.h
diff --git a/src/palimpsest/gdutypes.h b/src/disks/gdutypes.h
similarity index 100%
rename from src/palimpsest/gdutypes.h
rename to src/disks/gdutypes.h
diff --git a/src/palimpsest/gduunlockdialog.c b/src/disks/gduunlockdialog.c
similarity index 100%
rename from src/palimpsest/gduunlockdialog.c
rename to src/disks/gduunlockdialog.c
diff --git a/src/palimpsest/gduunlockdialog.h b/src/disks/gduunlockdialog.h
similarity index 100%
rename from src/palimpsest/gduunlockdialog.h
rename to src/disks/gduunlockdialog.h
diff --git a/src/palimpsest/gduutils.c b/src/disks/gduutils.c
similarity index 100%
rename from src/palimpsest/gduutils.c
rename to src/disks/gduutils.c
diff --git a/src/palimpsest/gduutils.h b/src/disks/gduutils.h
similarity index 100%
rename from src/palimpsest/gduutils.h
rename to src/disks/gduutils.h
diff --git a/src/palimpsest/gduvolumegrid.c b/src/disks/gduvolumegrid.c
similarity index 100%
rename from src/palimpsest/gduvolumegrid.c
rename to src/disks/gduvolumegrid.c
diff --git a/src/palimpsest/gduvolumegrid.h b/src/disks/gduvolumegrid.h
similarity index 100%
rename from src/palimpsest/gduvolumegrid.h
rename to src/disks/gduvolumegrid.h
diff --git a/src/palimpsest/gduwindow.c b/src/disks/gduwindow.c
similarity index 99%
rename from src/palimpsest/gduwindow.c
rename to src/disks/gduwindow.c
index db695e7..c80aeeb 100644
--- a/src/palimpsest/gduwindow.c
+++ b/src/disks/gduwindow.c
@@ -50,7 +50,7 @@
#include "gdurestorediskimagedialog.h"
#include "gduchangepassphrasedialog.h"
/* Keep in sync with tabs in palimpsest.ui file */
typedef enum
{
DETAILS_PAGE_NOT_SELECTED,
@@ -137,7 +137,7 @@ static const struct {
{G_STRUCT_OFFSET (GduWindow, device_toolbar_attach_disk_image_button), "device-tree-attach-disk-image-button"},
{G_STRUCT_OFFSET (GduWindow, device_toolbar_detach_disk_image_button), "device-tree-detach-disk-image-button"},
{G_STRUCT_OFFSET (GduWindow, device_treeview), "device-tree-treeview"},
- {G_STRUCT_OFFSET (GduWindow, details_notebook), "palimpsest-notebook"},
+ {G_STRUCT_OFFSET (GduWindow, details_notebook), "disks-notebook"},
{G_STRUCT_OFFSET (GduWindow, devtab_drive_table), "devtab-drive-table"},
{G_STRUCT_OFFSET (GduWindow, devtab_drive_box), "devtab-drive-box"},
{G_STRUCT_OFFSET (GduWindow, devtab_drive_vbox), "devtab-drive-vbox"},
@@ -883,7 +883,7 @@ gdu_window_constructed (GObject *object)
G_OBJECT_CLASS (gdu_window_parent_class)->constructed (object);
/* load UI file */
- gdu_application_new_widget (window->application, "palimpsest.ui", NULL, &window->builder);
+ gdu_application_new_widget (window->application, "disks.ui", NULL, &window->builder);
/* set up widgets */
for (n = 0; widget_mapping[n].name != NULL; n++)
@@ -50,7 +50,7 @@
#include "gdurestorediskimagedialog.h"
#include "gduchangepassphrasedialog.h"
-/* Keep in sync with tabs in palimpsest.ui file */
+/* Keep in sync with tabs in disks.ui file */
typedef enum
{
diff --git a/src/palimpsest/gduwindow.h b/src/disks/gduwindow.h
similarity index 100%
rename from src/palimpsest/gduwindow.h
rename to src/disks/gduwindow.h
diff --git a/src/palimpsest/main.c b/src/disks/main.c
similarity index 100%
rename from src/palimpsest/main.c
rename to src/disks/main.c
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]